@@ -36,6 +36,8 @@ import os
 import socket
 import sys
 
+import anyjson
+
 from couchdbkit.exceptions import DocsPathNotFound
 from couchdbkit.resource import ResourceNotFound
 from couchdbkit.utils import *
@@ -51,7 +53,7 @@ class BaseDocsLoader(object):
 
         from couchdbkit import BaseDocsLoader
         import os
-        import simplejson as json
+        import anyjson
 
         class MyDocsLoader(BaseDocsLoader):
 
@@ -62,7 +64,7 @@ class BaseDocsLoader(object):
                 if not os.path.exists(path):
                     raise DocsPathNotFound
                 with file(path) as f:
-                    source = json.loads(f.read().decode('utf-8'))
+                    source = anyjson.deserialize(f.read().decode('utf-8'))
                 return source
     """
     
@@ -315,13 +317,29 @@ class FileSystemDocsLoader(BaseDocsLoader):
             if not 'couchapp' in design_doc:
                 design_doc['couchapp'] = {}
 
-            if 'shows' in design_doc:
-                package_shows(design_doc, design_doc['shows'], app_dir, objects, verbose=verbose)
-
-            if 'lists' in design_doc:
-                package_shows(design_doc, design_doc['lists'], app_dir, objects, verbose=verbose)
+            for funs in ['shows', 'lists', 'updates', 'filters']:
+                if funs in design_doc:
+                    package_shows(design_doc, design_doc[funs], app_dir, objects, verbose=verbose)
 
             if 'views' in design_doc:
+                # clean views
+                # we remove empty views and malformed from the list
+                # of pushed views. We also clean manifest
+                views = {}
+                dmanifest = {}
+                for i, fname in enumerate(manifest):
+                    if fname.startswith("views/") and fname != "views/":
+                        name, ext = os.path.splitext(fname)
+                        if name.endswith('/'):
+                            name = name[:-1]
+                        dmanifest[name] = i
+
+                for vname, value in design_doc['views'].iteritems():
+                    if value and isinstance(value, dict):
+                        views[vname] = value
+                    else:
+                        del manifest[dmanifest["views/%s" % vname]]
+                design_doc['views'] = views
                 package_views(design_doc, design_doc["views"], app_dir, objects, verbose=verbose)
 
             couchapp = design_doc.get('couchapp', False)
@@ -396,7 +414,7 @@ class FileSystemDocsLoader(BaseDocsLoader):
                         
                 if name.endswith('.json'):
                     try:
-                        content = json.loads(content)
+                        content = anyjson.deserialize(content)
                     except ValueError:
                         if verbose >= 2:
                             print >>sys.stderr, "Json invalid in %s" % current_path
